"""Common filenames and locations for topographic data, meshes and outputs.
Author: John Jakeman, The Australian National University (2008)
"""

from os import sep, environ, getenv, getcwd
from os.path import expanduser
import sys
from time import localtime, strftime, gmtime
from anuga.utilities.polygon import read_polygon, plot_polygons, \
                                    polygon_area, is_inside_polygon
from anuga.coordinate_transforms.redfearn import convert_from_latlon_to_utm
from time import localtime, strftime

def convert_arcgis_latlon_list_to_utm(points):
     #Used because arc gis produced csv files put lat lon in
     #reverse order to those accpeted by convert_latlon_to_utm()
     
     from anuga.coordinate_transforms.geo_reference import Geo_reference
     from anuga.coordinate_transforms.redfearn import redfearn
     old_geo = Geo_reference() 
     utm_points = []
     for point in points:
         zone, easting, northing = redfearn(float(point[1]),float(point[0]))
         new_geo = Geo_reference(zone)
         old_geo.reconcile_zones(new_geo) 
         utm_points.append([easting,northing])

     return utm_points, old_geo.get_zone()

###############################
# Domain definitions
###############################

# Bathymetry and topography filenames
dir='data'

time = strftime('%Y%m%d_%H%M%S',localtime()) #gets time for new dir
poor_combined_dir_name = dir+sep+'poor_phuket_bathymetry'
good_combined_dir_name = dir+sep+'good_phuket_bathymetry'
meshname = 'phuket_mesh'
mesh_elevname = 'phuket_mesh_elev'
boundary_most_in = dir+sep+'out'
boundary_most_out = dir+sep+'most_boundary_condition'

dir='mesh_polygons'
#extent = 'extent.csv'
extent = 'boundary_new_pts.csv'
# bounding polygon for study area
bounding_polygon = read_polygon(dir+sep+extent)
patong_bay_polygon = read_polygon(dir+sep+'patong_bay_polygon.csv')

###############################
# Interior region definitions
###############################

island_south = read_polygon(dir+sep+'south_island.csv')
island_south2 = read_polygon(dir+sep+'south_island2.csv')
island_north = read_polygon(dir+sep+'north_island.csv')
bay = read_polygon(dir+sep+'bay.csv')
patong = read_polygon(dir+sep+'patong.csv')
contour20m = read_polygon(dir+sep+'20m.csv')



#max_extent_of MOST file
#east  = 94.93325
#west  = 80.0003
#north = 10.0000
#south = -4.9330

#max_extent_of MOST file should be
#east  = 104.0 
#west  = 80.0
#north = 10.0
#south = -5.0

#max_extent of ol simulation is why does this work and not below
#7.40911081272 8.71484358635 99.1683687224 97.513856322

#max extent of clipped MOST file
east  = 100
west  = 96.0
north = 9.0
south = 6.0


